==> qtmobilehotspot_0.2.tar.gz: qtmobilehotspot-0.2/qtMobileHotspot/fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>AccessPointGUI</name>
    <message>
        <location filename="src/accesspointgui.cpp" line="39"/>
        <source>Invalid key</source>
        <translation>Clé invalide</translation>
    </message>
    <message>
        <location filename="src/accesspointgui.cpp" line="39"/>
        <source>Keys must have a length of 5 or 13. Your key has been tweaked according to this.</source>
        <translation>Les clés doivent avoir une longueur de 5 ou 13. La clé a été changée selon ce critère.</translation>
    </message>
</context>
<context>
    <name>AccessPointGUIClass</name>
    <message>
        <location filename="src/accesspointgui.ui" line="14"/>
        <location filename="src/ui_accesspointgui.h" line="104"/>
        <source>Access Point</source>
        <translation>Hotspot Wifi</translation>
    </message>
    <message>
        <location filename="src/accesspointgui.ui" line="22"/>
        <location filename="src/ui_accesspointgui.h" line="105"/>
        <source>Hotspot name :</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <location filename="src/accesspointgui.ui" line="32"/>
        <location filename="src/ui_accesspointgui.h" line="106"/>
        <source>Security :</source>
        <translation>Sécurité :</translation>
    </message>
    <message>
        <location filename="src/accesspointgui.ui" line="52"/>
        <location filename="src/ui_accesspointgui.h" line="107"/>
        <source>Key :</source>
        <translation>Clé :</translation>
    </message>
    <message>
        <location filename="src/accesspointgui.ui" line="59"/>
        <location filename="src/ui_accesspointgui.h" line="108"/>
        <source>Enable WEP encryption</source>
        <translation>Activer le cryptage WEP</translation>
    </message>
</context>
<context>
    <name>InternetAccessGUI</name>
    <message>
        <location filename="src/internetaccessgui.cpp" line="15"/>
        <source>No change</source>
        <translation>Ne pas changer</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.cpp" line="16"/>
        <source>2G only</source>
        <translation>2G seulement</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.cpp" line="17"/>
        <source>3G only</source>
        <translation>3G seulement</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.cpp" line="18"/>
        <source>2G/3G</source>
        <oldsource>2G &amp; 3G</oldsource>
        <translation>2G/3G</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.cpp" line="78"/>
        <source>Invalid network</source>
        <translation>Réseau invalide</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.cpp" line="78"/>
        <source>The entered network is invalid. The default value will be used.</source>
        <translation>Le réseau indiqué est invalide. La valeur par défaut sera utilisée.</translation>
    </message>
</context>
<context>
    <name>InternetAccessGUIClass</name>
    <message>
        <location filename="src/internetaccessgui.ui" line="14"/>
        <location filename="src/ui_internetaccessgui.h" line="109"/>
        <source>Networking</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.ui" line="29"/>
        <location filename="src/ui_internetaccessgui.h" line="110"/>
        <source>APN name : </source>
        <translation>Nom APN :</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.ui" line="39"/>
        <location filename="src/ui_internetaccessgui.h" line="111"/>
        <source>LAN IP (/24) :</source>
        <oldsource>Network IP (/24) :</oldsource>
        <translation>IP LAN (/24) :</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.ui" line="49"/>
        <location filename="src/ui_internetaccessgui.h" line="112"/>
        <source>Share internet access</source>
        <translation>Partage internet</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.ui" line="59"/>
        <location filename="src/ui_internetaccessgui.h" line="113"/>
        <source>2G/3G switcher :</source>
        <translation>Switch 2G/3G :</translation>
    </message>
</context>
<context>
    <name>MobileHotspotConfiguration</name>
    <message>
        <source>No encryption</source>
        <translation type="obsolete">Non-crypté</translation>
    </message>
</context>
<context>
    <name>MobileHotspotGUI</name>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="49"/>
        <source>Closing the program</source>
        <translation>Fermeture</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="49"/>
        <source>Hotspot is still active ! Do you want to stop it ?</source>
        <translation>Le hotspot est actif ! Voulez-vous l&apos;arrêter ?</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="142"/>
        <source>Developped by</source>
        <translation>Développé par</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="143"/>
        <source>Some elements are inspired from MobileHotSpot by</source>
        <translation>Quelques éléments ont été inspirés par MobileHotSpot de</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="144"/>
        <source>This program allows your N900 to be used as a hotspot.</source>
        <translation>Ce programme fait de votre N900 un hotspot.</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="145"/>
        <source>Share your data connection with your other devices !</source>
        <translation>Partagez votre connexion avec vos autres appareils !</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="146"/>
        <source>About this program...</source>
        <translation>A propos...</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="152"/>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="152"/>
        <source>No encryption</source>
        <translation>Non-crypté</translation>
    </message>
    <message>
        <source>2G only</source>
        <translation type="obsolete">2G</translation>
    </message>
    <message>
        <source>3G only</source>
        <translation type="obsolete">3G</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="159"/>
        <source>2G</source>
        <translation>2G</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="161"/>
        <source>3G</source>
        <translation>3G</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="163"/>
        <source>2G/3G</source>
        <oldsource>2G &amp; 3G</oldsource>
        <translation>2G/3G</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="167"/>
        <source>With internet</source>
        <translation>Avec internet</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="167"/>
        <source>Without internet</source>
        <translation>Sans internet</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="171"/>
        <source>Wifi</source>
        <translation>Wifi</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="172"/>
        <source>USB</source>
        <translation>USB</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="257"/>
        <source>Error while loading system modules, are you running the power kernel ?</source>
        <translation>Erreur au chargement des modules système. Utilisez-vous le power-kernel ?</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="269"/>
        <location filename="src/mobilehotspotgui.cpp" line="281"/>
        <source>Error while disconnecting previous internet connection</source>
        <translation>Erreur à la désactivation de la connection internet</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="274"/>
        <source>Error while connecting to the chosen APN</source>
        <translation>Erreur à la connection à l&apos;APN choisi</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="292"/>
        <source>Error while checking USB mode, are you in PC Suite mode ?</source>
        <translation>Erreur à la vérification du mode USB, êtes vous en mode PC Suite ?</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="297"/>
        <source>Error while preparing the USB interface</source>
        <translation>Erreur à la préparation de l&apos;interface USB</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="305"/>
        <source>Error while preparing the Wifi interface</source>
        <translation>Erreur à la préparation de l&apos;interface Wifi</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="311"/>
        <source>Error (timeout) while stopping the DHCP/DNS server</source>
        <translation>Erreur (timeout) à l&apos;arrêt du serveur DNS/DHCP</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="332"/>
        <source>Failed to start the hotspot</source>
        <translation>Echec du démarrage du hotspot</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="363"/>
        <source>Hotspot started successfully</source>
        <translation>Hotspot démarré avec succès</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="503"/>
        <source>Hotspot stopped successfully</source>
        <translation>Hotspot arrêté avec succès</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="503"/>
        <source>Hotspot stopped with errors</source>
        <translation>Hotspot arrêté avec erreurs</translation>
    </message>
</context>
<context>
    <name>MobileHotspotGUIClass</name>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="14"/>
        <location filename="src/ui_mobilehotspotgui.h" line="197"/>
        <source>Qt Mobile Hotspot</source>
        <translation>Qt Mobile Hotspot</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="53"/>
        <location filename="src/ui_mobilehotspotgui.h" line="199"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="82"/>
        <location filename="src/ui_mobilehotspotgui.h" line="200"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="152"/>
        <location filename="src/ui_mobilehotspotgui.h" line="201"/>
        <source>AP settings...</source>
        <translation>Hotspot Wifi...</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="191"/>
        <location filename="src/ui_mobilehotspotgui.h" line="202"/>
        <source>Network settings...</source>
        <translation>Réseau...</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="213"/>
        <location filename="src/ui_mobilehotspotgui.h" line="203"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="219"/>
        <location filename="src/ui_mobilehotspotgui.h" line="204"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="227"/>
        <location filename="src/ui_mobilehotspotgui.h" line="198"/>
        <source>About Qt Mobile Hotspot</source>
        <oldsource>About qtMobileHotspot</oldsource>
        <translation>A propos de Qt Mobile Hotspot</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No encryption</source>
        <translation type="obsolete">Non-crypté</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation type="obsolete">WEP</translation>
    </message>
    <message>
        <source>USB</source>
        <translation type="obsolete">USB</translation>
    </message>
    <message>
        <source>Wifi</source>
        <translation type="obsolete">Wifi</translation>
    </message>
</context>
</TS>

==> qtmobilehotspot_0.3.tar.gz: qtmobilehotspot-0.3/qtMobileHotspot/fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>AccessPointGUI</name>
    <message>
        <location filename="src/accesspointgui.cpp" line="43"/>
        <source>Invalid key</source>
        <translation>Clé invalide</translation>
    </message>
    <message>
        <location filename="src/accesspointgui.cpp" line="43"/>
        <source>Keys must have a length of 5 or 13. Your key has been tweaked according to this.</source>
        <translation>Les clés doivent avoir une longueur de 5 ou 13. La clé a été changée selon ce critère.</translation>
    </message>
</context>
<context>
    <name>AccessPointGUIClass</name>
    <message>
        <location filename="src/accesspointgui.ui" line="14"/>
        <source>Access Point</source>
        <translation>Hotspot Wifi</translation>
    </message>
    <message>
        <location filename="src/accesspointgui.ui" line="29"/>
        <source>Hotspot name :</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <location filename="src/accesspointgui.ui" line="39"/>
        <source>Security :</source>
        <translation>Sécurité :</translation>
    </message>
    <message>
        <location filename="src/accesspointgui.ui" line="59"/>
        <source>Key :</source>
        <translation>Clé :</translation>
    </message>
    <message>
        <location filename="src/accesspointgui.ui" line="66"/>
        <source>Enable WEP encryption</source>
        <translation>Activer le cryptage WEP</translation>
    </message>
    <message>
        <location filename="src/accesspointgui.ui" line="73"/>
        <source>Disable power-saving</source>
        <oldsource>Enable power management</oldsource>
        <translation>Désactiver l&apos;économie d&apos;énergie</translation>
    </message>
</context>
<context>
    <name>InternetAccessGUI</name>
    <message>
        <location filename="src/internetaccessgui.cpp" line="15"/>
        <source>No change</source>
        <translation>Ne pas changer</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.cpp" line="16"/>
        <source>2G only</source>
        <translation>2G seulement</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.cpp" line="17"/>
        <source>3G only</source>
        <translation>3G seulement</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.cpp" line="18"/>
        <source>2G/3G</source>
        <oldsource>2G &amp; 3G</oldsource>
        <translation>2G/3G</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.cpp" line="79"/>
        <source>Invalid network</source>
        <translation>Réseau invalide</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.cpp" line="79"/>
        <source>The entered network is invalid. The default value will be used.</source>
        <translation>Le réseau indiqué est invalide. La valeur par défaut sera utilisée.</translation>
    </message>
</context>
<context>
    <name>InternetAccessGUIClass</name>
    <message>
        <location filename="src/internetaccessgui.ui" line="14"/>
        <source>Networking</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.ui" line="29"/>
        <source>APN name : </source>
        <translation>Nom APN :</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.ui" line="39"/>
        <source>LAN IP (/24) :</source>
        <oldsource>Network IP (/24) :</oldsource>
        <translation>IP LAN (/24) :</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.ui" line="49"/>
        <source>Share internet access</source>
        <translation>Partage internet</translation>
    </message>
    <message>
        <location filename="src/internetaccessgui.ui" line="59"/>
        <source>2G/3G switcher :</source>
        <translation>Switch 2G/3G :</translation>
    </message>
</context>
<context>
    <name>MobileHotspotConfiguration</name>
    <message>
        <source>No encryption</source>
        <translation type="obsolete">Non-crypté</translation>
    </message>
</context>
<context>
    <name>MobileHotspotGUI</name>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="50"/>
        <source>Closing the program</source>
        <translation>Fermeture</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="50"/>
        <source>Hotspot is still active ! Do you want to stop it ?</source>
        <translation>Le hotspot est actif ! Voulez-vous l&apos;arrêter ?</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="143"/>
        <source>Developped by</source>
        <translation>Développé par</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="144"/>
        <source>Some elements are inspired from MobileHotSpot by</source>
        <translation>Quelques éléments ont été inspirés par MobileHotSpot de</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="145"/>
        <source>This program allows your N900 to be used as a hotspot.</source>
        <translation>Ce programme fait de votre N900 un hotspot.</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="146"/>
        <source>Share your data connection with your other devices !</source>
        <translation>Partagez votre connexion avec vos autres appareils !</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="147"/>
        <source>About this program...</source>
        <translation>A propos...</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="153"/>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="153"/>
        <source>No encryption</source>
        <translation>Non-crypté</translation>
    </message>
    <message>
        <source>2G only</source>
        <translation type="obsolete">2G</translation>
    </message>
    <message>
        <source>3G only</source>
        <translation type="obsolete">3G</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="155"/>
        <source>Disable power-saving</source>
        <translation>Sans économie d&apos;énergie</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="163"/>
        <source>2G</source>
        <translation>2G</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="165"/>
        <source>3G</source>
        <translation>3G</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="167"/>
        <source>2G/3G</source>
        <oldsource>2G &amp; 3G</oldsource>
        <translation>2G/3G</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="172"/>
        <source>With internet</source>
        <translation>Avec internet</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="172"/>
        <source>Without internet</source>
        <translation>Sans internet</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="176"/>
        <source>Wifi</source>
        <translation>Wifi</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="177"/>
        <source>USB</source>
        <translation>USB</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="268"/>
        <source>Error : LAN and Internet are both using the Wifi interface, please use a LAN on USB</source>
        <translation>Erreur : Le LAN et Internet sont tous deux sur l&apos;interface Wifi, veuillez utiliser un LAN sur USB</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="269"/>
        <source>Invalid parameters</source>
        <translation>Paramètres invalides</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="292"/>
        <source>Error while loading system modules, are you running the power kernel ?</source>
        <translation>Erreur au chargement des modules système. Utilisez-vous le power-kernel ?</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="305"/>
        <location filename="src/mobilehotspotgui.cpp" line="324"/>
        <source>Error while disconnecting previous internet connection</source>
        <translation>Erreur à la désactivation de la connection internet</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="317"/>
        <source>Error while connecting to the chosen APN</source>
        <translation>Erreur à la connection à l&apos;APN choisi</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="338"/>
        <source>Error while checking USB mode, are you in PC Suite mode ?</source>
        <translation>Erreur à la vérification du mode USB, êtes vous en mode PC Suite ?</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="343"/>
        <source>Error while preparing the USB interface</source>
        <translation>Erreur à la préparation de l&apos;interface USB</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="351"/>
        <source>Error while preparing the Wifi interface</source>
        <translation>Erreur à la préparation de l&apos;interface Wifi</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="357"/>
        <source>Error (timeout) while stopping the DHCP/DNS server</source>
        <translation>Erreur (timeout) à l&apos;arrêt du serveur DNS/DHCP</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="378"/>
        <source>Failed to start the hotspot</source>
        <translation>Echec du démarrage du hotspot</translation>
    </message>
    <message>
        <source>With power management</source>
        <translation type="obsolete">Avec économie d&apos;énergie</translation>
    </message>
    <message>
        <source>No power management</source>
        <translation type="obsolete">Sans économie d&apos;énergie</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="409"/>
        <source>Hotspot started successfully</source>
        <translation>Hotspot démarré avec succès</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="560"/>
        <source>Hotspot stopped successfully</source>
        <translation>Hotspot arrêté avec succès</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.cpp" line="560"/>
        <source>Hotspot stopped with errors</source>
        <translation>Hotspot arrêté avec erreurs</translation>
    </message>
</context>
<context>
    <name>MobileHotspotGUIClass</name>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="14"/>
        <source>Qt Mobile Hotspot</source>
        <translation>Qt Mobile Hotspot</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="53"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="82"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>AP settings...</source>
        <translation type="obsolete">Hotspot Wifi...</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="152"/>
        <source>Wifi...</source>
        <translation>Wifi...</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="191"/>
        <source>Networking...</source>
        <oldsource>Network settings...</oldsource>
        <translation>Réseau...</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="213"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="219"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location filename="src/mobilehotspotgui.ui" line="227"/>
        <source>About Qt Mobile Hotspot</source>
        <oldsource>About qtMobileHotspot</oldsource>
        <translation>A propos de Qt Mobile Hotspot</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No encryption</source>
        <translation type="obsolete">Non-crypté</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation type="obsolete">WEP</translation>
    </message>
    <message>
        <source>USB</source>
        <translation type="obsolete">USB</translation>
    </message>
    <message>
        <source>Wifi</source>
        <translation type="obsolete">Wifi</translation>
    </message>
</context>
</TS>
